History
=======

1.1 (2016-05-25)
----------------

- Support for python ``uuid`` module
  [jensens]

- more generic ``basex`` base class and special ``basej`` class.
  [jensens]


1.0
---

- initial implementation [rnixx, jensens]
